Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(249)

Unified Diff: chrome/browser/ui/webui/print_preview/print_preview_ui.h

Issue 388783003: Add support to send print preset options in one message (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Review feedback (update param structure) Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/print_preview/print_preview_ui.h
diff --git a/chrome/browser/ui/webui/print_preview/print_preview_ui.h b/chrome/browser/ui/webui/print_preview/print_preview_ui.h
index 7f32261dad683cb41ea074ec27d46de9b11e7d86..ee887ac4308b2e01697ebc1d9fb8b93be8f5799c 100644
--- a/chrome/browser/ui/webui/print_preview/print_preview_ui.h
+++ b/chrome/browser/ui/webui/print_preview/print_preview_ui.h
@@ -16,6 +16,7 @@ class PrintPreviewDataService;
class PrintPreviewHandler;
struct PrintHostMsg_DidGetPreviewPageCount_Params;
struct PrintHostMsg_RequestPrintPreview_Params;
+struct PrintHostMsg_SetOptionsFromDocument_Params;
namespace base {
class RefCountedBytes;
@@ -139,9 +140,9 @@ class PrintPreviewUI : public ConstrainedWebDialogUI {
// Reload the printers list.
void OnReloadPrintersList();
- // Notifies the WebUI that the pdf print scaling option is disabled by
- // default.
- void OnPrintPreviewScalingDisabled();
+ // Notifies the WebUI to set print preset options from source PDF.
+ void OnSetOptionsFromDocument(
+ const PrintHostMsg_SetOptionsFromDocument_Params& params);
// Allows tests to wait until the print preview dialog is loaded. Optionally
// also instructs the dialog to auto-cancel, which is used for testing only.

Powered by Google App Engine
This is Rietveld 408576698